==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/DeploymentDetailsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class DeploymentDetailsFluentImpl<A extends io.fabric8.openshift.api.model.DeploymentDetailsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.DeploymentDetailsFluent<A>{
  public DeploymentDetailsFluentImpl() {
  }
  public DeploymentDetailsFluentImpl(io.fabric8.openshift.api.model.DeploymentDetails instance) {
    this.withCauses(instance.getCauses()); 
    this.withMessage(instance.getMessage()); 
  }
  private java.util.List<io.fabric8.openshift.api.model.DeploymentCauseBuilder> causes =  new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>();
  private java.lang.String message;
  public A addToCauses(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item) {
    if (this.causes == null) {this.causes = new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>();}
    io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);_visitables.get("causes").add(index >= 0 ? index : _visitables.get("causes").size(), builder);this.causes.add(index >= 0 ? index : causes.size(), builder); return (A)this;
  }
  public A setToCauses(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item) {
    if (this.causes == null) {this.causes = new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>();}
    io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);
    if (index < 0 || index >= _visitables.get("causes").size()) { _visitables.get("causes").add(builder); } else { _visitables.get("causes").set(index, builder);}
    if (index < 0 || index >= causes.size()) { causes.add(builder); } else { causes.set(index, builder);}
     return (A)this;
  }
  public A addToCauses(io.fabric8.openshift.api.model.DeploymentCause... items) {
    if (this.causes == null) {this.causes = new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>();}
    for (io.fabric8.openshift.api.model.DeploymentCause item : items) {io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);_visitables.get("causes").add(builder);this.causes.add(builder);} return (A)this;
  }
  public A addAllToCauses(java.util.Collection<io.fabric8.openshift.api.model.DeploymentCause> items) {
    if (this.causes == null) {this.causes = new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>();}
    for (io.fabric8.openshift.api.model.DeploymentCause item : items) {io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);_visitables.get("causes").add(builder);this.causes.add(builder);} return (A)this;
  }
  public A removeFromCauses(io.fabric8.openshift.api.model.DeploymentCause... items) {
    for (io.fabric8.openshift.api.model.DeploymentCause item : items) {io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);_visitables.get("causes").remove(builder);if (this.causes != null) {this.causes.remove(builder);}} return (A)this;
  }
  public A removeAllFromCauses(java.util.Collection<io.fabric8.openshift.api.model.DeploymentCause> items) {
    for (io.fabric8.openshift.api.model.DeploymentCause item : items) {io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);_visitables.get("causes").remove(builder);if (this.causes != null) {this.causes.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromCauses(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate) {
    if (causes == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.DeploymentCauseBuilder> each = causes.iterator();
    final List visitables = _visitables.get("causes");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildCauses instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.DeploymentCause> getCauses() {
    return build(causes);
  }
  public java.util.List<io.fabric8.openshift.api.model.DeploymentCause> buildCauses() {
    return build(causes);
  }
  public io.fabric8.openshift.api.model.DeploymentCause buildCause(java.lang.Integer index) {
    return this.causes.get(index).build();
  }
  public io.fabric8.openshift.api.model.DeploymentCause buildFirstCause() {
    return this.causes.get(0).build();
  }
  public io.fabric8.openshift.api.model.DeploymentCause buildLastCause() {
    return this.causes.get(causes.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.DeploymentCause buildMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate) {
    for (io.fabric8.openshift.api.model.DeploymentCauseBuilder item: causes) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate) {
    for (io.fabric8.openshift.api.model.DeploymentCauseBuilder item: causes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCauses(java.util.List<io.fabric8.openshift.api.model.DeploymentCause> causes) {
    if (this.causes != null) { _visitables.get("causes").removeAll(this.causes);}
    if (causes != null) {this.causes = new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>(); for (io.fabric8.openshift.api.model.DeploymentCause item : causes){this.addToCauses(item);}} else { this.causes = null;} return (A) this;
  }
  public A withCauses(io.fabric8.openshift.api.model.DeploymentCause... causes) {
    if (this.causes != null) {this.causes.clear();}
    if (causes != null) {for (io.fabric8.openshift.api.model.DeploymentCause item :causes){ this.addToCauses(item);}} return (A) this;
  }
  public java.lang.Boolean hasCauses() {
    return causes != null && !causes.isEmpty();
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> addNewCause() {
    return new io.fabric8.openshift.api.model.DeploymentDetailsFluentImpl.CausesNestedImpl();
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> addNewCauseLike(io.fabric8.openshift.api.model.DeploymentCause item) {
    return new io.fabric8.openshift.api.model.DeploymentDetailsFluentImpl.CausesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> setNewCauseLike(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item) {
    return new io.fabric8.openshift.api.model.DeploymentDetailsFluentImpl.CausesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editCause(java.lang.Integer index) {
    if (causes.size() <= index) throw new RuntimeException("Can't edit causes. Index exceeds size.");
    return setNewCauseLike(index, buildCause(index));
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editFirstCause() {
    if (causes.size() == 0) throw new RuntimeException("Can't edit first causes. The list is empty.");
    return setNewCauseLike(0, buildCause(0));
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editLastCause() {
    int index = causes.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last causes. The list is empty.");
    return setNewCauseLike(index, buildCause(index));
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate) {
    int index = -1;
    for (int i=0;i<causes.size();i++) { 
    if (predicate.test(causes.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching causes. No match found.");
    return setNewCauseLike(index, buildCause(index));
  }
  public java.lang.String getMessage() {
    return this.message;
  }
  public A withMessage(java.lang.String message) {
    this.message=message; return (A) this;
  }
  public java.lang.Boolean hasMessage() {
    return this.message != null;
  }
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0) {
    return (A)withMessage(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DeploymentDetailsFluentImpl that = (DeploymentDetailsFluentImpl) o;
    if (causes != null ? !causes.equals(that.causes) :that.causes != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(causes,  message,  super.hashCode());
  }
  public class CausesNestedImpl<N> extends io.fabric8.openshift.api.model.DeploymentCauseFluentImpl<io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<N>> implements io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CausesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(this, item);
    }
    CausesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(this);
    }
    io.fabric8.openshift.api.model.DeploymentCauseBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) DeploymentDetailsFluentImpl.this.setToCauses(index,builder.build());
    }
    public N endCause() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/DeploymentDetailsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class DeploymentDetailsFluentImpl<A extends io.fabric8.openshift.api.model.DeploymentDetailsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.DeploymentDetailsFluent<A>{
  public DeploymentDetailsFluentImpl() {
  }
  public DeploymentDetailsFluentImpl(io.fabric8.openshift.api.model.DeploymentDetails instance) {
    this.withCauses(instance.getCauses()); 
    this.withMessage(instance.getMessage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.DeploymentCauseBuilder> causes =  new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>();
  private java.lang.String message;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToCauses(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item) {
    if (this.causes == null) {this.causes = new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>();}
    io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);_visitables.get("causes").add(index >= 0 ? index : _visitables.get("causes").size(), builder);this.causes.add(index >= 0 ? index : causes.size(), builder); return (A)this;
  }
  public A setToCauses(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item) {
    if (this.causes == null) {this.causes = new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>();}
    io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);
    if (index < 0 || index >= _visitables.get("causes").size()) { _visitables.get("causes").add(builder); } else { _visitables.get("causes").set(index, builder);}
    if (index < 0 || index >= causes.size()) { causes.add(builder); } else { causes.set(index, builder);}
     return (A)this;
  }
  public A addToCauses(io.fabric8.openshift.api.model.DeploymentCause... items) {
    if (this.causes == null) {this.causes = new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>();}
    for (io.fabric8.openshift.api.model.DeploymentCause item : items) {io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);_visitables.get("causes").add(builder);this.causes.add(builder);} return (A)this;
  }
  public A addAllToCauses(java.util.Collection<io.fabric8.openshift.api.model.DeploymentCause> items) {
    if (this.causes == null) {this.causes = new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>();}
    for (io.fabric8.openshift.api.model.DeploymentCause item : items) {io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);_visitables.get("causes").add(builder);this.causes.add(builder);} return (A)this;
  }
  public A removeFromCauses(io.fabric8.openshift.api.model.DeploymentCause... items) {
    for (io.fabric8.openshift.api.model.DeploymentCause item : items) {io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);_visitables.get("causes").remove(builder);if (this.causes != null) {this.causes.remove(builder);}} return (A)this;
  }
  public A removeAllFromCauses(java.util.Collection<io.fabric8.openshift.api.model.DeploymentCause> items) {
    for (io.fabric8.openshift.api.model.DeploymentCause item : items) {io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(item);_visitables.get("causes").remove(builder);if (this.causes != null) {this.causes.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromCauses(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate) {
    if (causes == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.DeploymentCauseBuilder> each = causes.iterator();
    final List visitables = _visitables.get("causes");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.DeploymentCauseBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildCauses instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.DeploymentCause> getCauses() {
    return build(causes);
  }
  public java.util.List<io.fabric8.openshift.api.model.DeploymentCause> buildCauses() {
    return build(causes);
  }
  public io.fabric8.openshift.api.model.DeploymentCause buildCause(java.lang.Integer index) {
    return this.causes.get(index).build();
  }
  public io.fabric8.openshift.api.model.DeploymentCause buildFirstCause() {
    return this.causes.get(0).build();
  }
  public io.fabric8.openshift.api.model.DeploymentCause buildLastCause() {
    return this.causes.get(causes.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.DeploymentCause buildMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate) {
    for (io.fabric8.openshift.api.model.DeploymentCauseBuilder item: causes) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate) {
    for (io.fabric8.openshift.api.model.DeploymentCauseBuilder item: causes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCauses(java.util.List<io.fabric8.openshift.api.model.DeploymentCause> causes) {
    if (this.causes != null) { _visitables.get("causes").removeAll(this.causes);}
    if (causes != null) {this.causes = new java.util.ArrayList<io.fabric8.openshift.api.model.DeploymentCauseBuilder>(); for (io.fabric8.openshift.api.model.DeploymentCause item : causes){this.addToCauses(item);}} else { this.causes = null;} return (A) this;
  }
  public A withCauses(io.fabric8.openshift.api.model.DeploymentCause... causes) {
    if (this.causes != null) {this.causes.clear();}
    if (causes != null) {for (io.fabric8.openshift.api.model.DeploymentCause item :causes){ this.addToCauses(item);}} return (A) this;
  }
  public java.lang.Boolean hasCauses() {
    return causes != null && !causes.isEmpty();
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> addNewCause() {
    return new io.fabric8.openshift.api.model.DeploymentDetailsFluentImpl.CausesNestedImpl();
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> addNewCauseLike(io.fabric8.openshift.api.model.DeploymentCause item) {
    return new io.fabric8.openshift.api.model.DeploymentDetailsFluentImpl.CausesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> setNewCauseLike(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item) {
    return new io.fabric8.openshift.api.model.DeploymentDetailsFluentImpl.CausesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editCause(java.lang.Integer index) {
    if (causes.size() <= index) throw new RuntimeException("Can't edit causes. Index exceeds size.");
    return setNewCauseLike(index, buildCause(index));
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editFirstCause() {
    if (causes.size() == 0) throw new RuntimeException("Can't edit first causes. The list is empty.");
    return setNewCauseLike(0, buildCause(0));
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editLastCause() {
    int index = causes.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last causes. The list is empty.");
    return setNewCauseLike(index, buildCause(index));
  }
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate) {
    int index = -1;
    for (int i=0;i<causes.size();i++) { 
    if (predicate.test(causes.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching causes. No match found.");
    return setNewCauseLike(index, buildCause(index));
  }
  public java.lang.String getMessage() {
    return this.message;
  }
  public A withMessage(java.lang.String message) {
    this.message=message; return (A) this;
  }
  public java.lang.Boolean hasMessage() {
    return this.message != null;
  }
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0) {
    return (A)withMessage(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DeploymentDetailsFluentImpl that = (DeploymentDetailsFluentImpl) o;
    if (causes != null ? !causes.equals(that.causes) :that.causes != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(causes,  message,  additionalProperties,  super.hashCode());
  }
  public class CausesNestedImpl<N> extends io.fabric8.openshift.api.model.DeploymentCauseFluentImpl<io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<N>> implements io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CausesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(this, item);
    }
    CausesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.DeploymentCauseBuilder(this);
    }
    io.fabric8.openshift.api.model.DeploymentCauseBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) DeploymentDetailsFluentImpl.this.setToCauses(index,builder.build());
    }
    public N endCause() {
      return and();
    }
    
  }
  
}
